S3Object

Struct S3Object 

pub struct S3Object {
    pub bucket: String,
    pub key: String,
}
A bucket key pair for a S3Object, with conversion from S3 urls.

Fields

bucket: String

The bucket the object is in.

key: String

The key the in the bucket for the object.

Implementations

Source

impl S3Object

pub fn new(bucket: impl AsRef<str>, key: impl AsRef<str>) -> Self

Create a new S3Object using anything which can be treated as &str. Any leading / will be trimmed from the key. No validation is done against the bucket or key to ensure they meet the AWS requirements.