pub struct AsyncMultipartUpload<'a> { /* private fields */ }Expand description
A implementation of AsyncWrite for S3 objects using multipart uploads. By using multipart uploads constant memory usage can be achieved.
Note
On failure the multipart upload is not aborted. It is up to the
caller to call the S3 abortMultipartUpload API when required.
use cobalt_aws::s3::{AsyncMultipartUpload, Client, S3Object};
use cobalt_aws::config::load_from_env;
use futures::AsyncWriteExt;
let shared_config = load_from_env().await.unwrap();
let client = Client::new(&shared_config);
let dst = S3Object::new("my-bucket", "my-key");
let part_size = 5 * 1_048_576;
let mut writer = AsyncMultipartUpload::new(&client, &dst, part_size, None).await.unwrap();
let buffer_len = 6 * 1_048_576;
// Each part is uploaded as it's available
writer.write_all(&vec![0; buffer_len]).await.unwrap();
// The pending parts are uploaded and the multipart upload is completed
// on close.
writer.close().await.unwrap();Implementations
Sourceimpl<'a> AsyncMultipartUpload<'a>
impl<'a> AsyncMultipartUpload<'a>
Sourcepub async fn new(
client: &'a Client,
dst: &S3Object,
part_size: usize,
max_uploading_parts: Option<usize>,
) -> Result<AsyncMultipartUpload<'a>>
pub async fn new( client: &'a Client, dst: &S3Object, part_size: usize, max_uploading_parts: Option<usize>, ) -> Result<AsyncMultipartUpload<'a>>
Create a new AsyncMultipartUpload.
client- S3 client to use.dst- The S3Object to write the object into.part_size- How large, in bytes, each part should be. Must be larger than 5MIB and smaller that 5GIB.max_uploading_parts- How many parts to upload concurrently, Must be larger than 0 (defaults to 100).
Sourcepub async fn from(
client: &'a Client,
upload_id: String,
dst: &S3Object,
part_size: usize,
max_uploading_parts: Option<usize>,
) -> Result<AsyncMultipartUpload<'a>>
pub async fn from( client: &'a Client, upload_id: String, dst: &S3Object, part_size: usize, max_uploading_parts: Option<usize>, ) -> Result<AsyncMultipartUpload<'a>>
Import an existing AsyncMultipartUpload to continue uploading.
client- S3 client to use.upload_id- The multipart upload ID to resume.dst- The S3Object to write the object into.part_size- How large, in bytes, each part should be. Must be larger than 5MIB and smaller that 5GIB.max_uploading_parts- How many parts to upload concurrently, Must be larger than 0 (defaults to 100).
pub fn get_upload_id(&self) -> &str